from distutils.core import setup  # 从 Python 发布工具导入 setup 函数
setup(name='swfswf',
      version='2.0',
      description='Python Distribution Utilities',
      author='shenwenfang',
      author_email='1978626782@qq.com',
      url='https://swenfang.github.io/',
     )
